==> qucs-s-debug-24.4.0-1-x86_64.pkg.tar.zst: usr/src/debug/qucs-s/qucs-s-24.4.0/builddir/qucsator_rf/src/converter/parse_vcd.hpp <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_VCD_PARSE_VCD_HPP_INCLUDED
# define YY_VCD_PARSE_VCD_HPP_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int vcd_debug;
#endif

/* Token kinds.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    YYEMPTY = -2,
    YYEOF = 0,                     /* "end of file"  */
    YYerror = 256,                 /* error  */
    YYUNDEF = 257,                 /* "invalid token"  */
    t_END = 258,                   /* t_END  */
    t_COMMENT = 259,               /* t_COMMENT  */
    t_DATE = 260,                  /* t_DATE  */
    t_ENDDEFINITIONS = 261,        /* t_ENDDEFINITIONS  */
    t_SCOPE = 262,                 /* t_SCOPE  */
    t_TIMESCALE = 263,             /* t_TIMESCALE  */
    t_UPSCOPE = 264,               /* t_UPSCOPE  */
    t_VAR = 265,                   /* t_VAR  */
    t_VERSION = 266,               /* t_VERSION  */
    t_DUMPALL = 267,               /* t_DUMPALL  */
    t_DUMPOFF = 268,               /* t_DUMPOFF  */
    t_DUMPON = 269,                /* t_DUMPON  */
    t_DUMPVARS = 270,              /* t_DUMPVARS  */
    s_MODULE = 271,                /* s_MODULE  */
    s_TASK = 272,                  /* s_TASK  */
    s_FUNCTION = 273,              /* s_FUNCTION  */
    s_FORK = 274,                  /* s_FORK  */
    s_BEGIN = 275,                 /* s_BEGIN  */
    ONE = 276,                     /* ONE  */
    B = 277,                       /* B  */
    Z = 278,                       /* Z  */
    ZERO = 279,                    /* ZERO  */
    HASHMARK = 280,                /* HASHMARK  */
    U = 281,                       /* U  */
    R = 282,                       /* R  */
    TEN = 283,                     /* TEN  */
    HUNDRET = 284,                 /* HUNDRET  */
    PICO = 285,                    /* PICO  */
    MICRO = 286,                   /* MICRO  */
    NANO = 287,                    /* NANO  */
    FEMTO = 288,                   /* FEMTO  */
    SECOND = 289,                  /* SECOND  */
    MILLI = 290,                   /* MILLI  */
    EVENT = 291,                   /* EVENT  */
    INTEGER = 292,                 /* INTEGER  */
    PARAMETER = 293,               /* PARAMETER  */
    REAL = 294,                    /* REAL  */
    REG = 295,                     /* REG  */
    SUPPLY0 = 296,                 /* SUPPLY0  */
    SUPPLY1 = 297,                 /* SUPPLY1  */
    TIME = 298,                    /* TIME  */
    TRI = 299,                     /* TRI  */
    TRIAND = 300,                  /* TRIAND  */
    TRIOR = 301,                   /* TRIOR  */
    TRIREG = 302,                  /* TRIREG  */
    TRI0 = 303,                    /* TRI0  */
    TRI1 = 304,                    /* TRI1  */
    WAND = 305,                    /* WAND  */
    WIRE = 306,                    /* WIRE  */
    WOR = 307,                     /* WOR  */
    Real = 308,                    /* Real  */
    Binary = 309,                  /* Binary  */
    PositiveInteger = 310,         /* PositiveInteger  */
    PositiveHugeInteger = 311,     /* PositiveHugeInteger  */
    Identifier = 312,              /* Identifier  */
    IdentifierCode = 313,          /* IdentifierCode  */
    Reference = 314,               /* Reference  */
    InvalidCharacter = 315         /* InvalidCharacter  */
  };
  typedef enum yytokentype yytoken_kind_t;
#endif

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
union YYSTYPE
{
#line 79 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"

  char * ident;
  char * value;
  int integer;
  double real;
  enum vcd_vartypes vtype;
  enum vcd_scopes stype;
  struct vcd_vardef * vardef;
  struct vcd_change * change;
  struct vcd_scope * scope;
  struct vcd_changeset * changeset;
  struct vcd_range * range;

#line 138 "parse_vcd.hpp"

};
typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE vcd_lval;


int vcd_parse (void);


#endif /* !YY_VCD_PARSE_VCD_HPP_INCLUDED  */

==> qucs-s-debug-25.1.1-1-x86_64.pkg.tar.zst: usr/src/debug/qucs-s/qucs-s-25.1.1/builddir/qucsator_rf/src/converter/parse_vcd.hpp <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_VCD_PARSE_VCD_HPP_INCLUDED
# define YY_VCD_PARSE_VCD_HPP_INCLUDED
/* Debug traces.  */
#ifndef VCD_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define VCD_DEBUG 1
#  else
#   define VCD_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define VCD_DEBUG 0
# endif /* ! defined YYDEBUG */
#endif  /* ! defined VCD_DEBUG */
#if VCD_DEBUG
extern int vcd_debug;
#endif

/* Token kinds.  */
#ifndef VCD_TOKENTYPE
# define VCD_TOKENTYPE
  enum vcd_tokentype
  {
    VCD_EMPTY = -2,
    VCD_EOF = 0,                   /* "end of file"  */
    VCD_error = 256,               /* error  */
    VCD_UNDEF = 257,               /* "invalid token"  */
    t_END = 258,                   /* t_END  */
    t_COMMENT = 259,               /* t_COMMENT  */
    t_DATE = 260,                  /* t_DATE  */
    t_ENDDEFINITIONS = 261,        /* t_ENDDEFINITIONS  */
    t_SCOPE = 262,                 /* t_SCOPE  */
    t_TIMESCALE = 263,             /* t_TIMESCALE  */
    t_UPSCOPE = 264,               /* t_UPSCOPE  */
    t_VAR = 265,                   /* t_VAR  */
    t_VERSION = 266,               /* t_VERSION  */
    t_DUMPALL = 267,               /* t_DUMPALL  */
    t_DUMPOFF = 268,               /* t_DUMPOFF  */
    t_DUMPON = 269,                /* t_DUMPON  */
    t_DUMPVARS = 270,              /* t_DUMPVARS  */
    s_MODULE = 271,                /* s_MODULE  */
    s_TASK = 272,                  /* s_TASK  */
    s_FUNCTION = 273,              /* s_FUNCTION  */
    s_FORK = 274,                  /* s_FORK  */
    s_BEGIN = 275,                 /* s_BEGIN  */
    ONE = 276,                     /* ONE  */
    B = 277,                       /* B  */
    Z = 278,                       /* Z  */
    ZERO = 279,                    /* ZERO  */
    HASHMARK = 280,                /* HASHMARK  */
    U = 281,                       /* U  */
    R = 282,                       /* R  */
    TEN = 283,                     /* TEN  */
    HUNDRET = 284,                 /* HUNDRET  */
    PICO = 285,                    /* PICO  */
    MICRO = 286,                   /* MICRO  */
    NANO = 287,                    /* NANO  */
    FEMTO = 288,                   /* FEMTO  */
    SECOND = 289,                  /* SECOND  */
    MILLI = 290,                   /* MILLI  */
    EVENT = 291,                   /* EVENT  */
    INTEGER = 292,                 /* INTEGER  */
    PARAMETER = 293,               /* PARAMETER  */
    REAL = 294,                    /* REAL  */
    REG = 295,                     /* REG  */
    SUPPLY0 = 296,                 /* SUPPLY0  */
    SUPPLY1 = 297,                 /* SUPPLY1  */
    TIME = 298,                    /* TIME  */
    TRI = 299,                     /* TRI  */
    TRIAND = 300,                  /* TRIAND  */
    TRIOR = 301,                   /* TRIOR  */
    TRIREG = 302,                  /* TRIREG  */
    TRI0 = 303,                    /* TRI0  */
    TRI1 = 304,                    /* TRI1  */
    WAND = 305,                    /* WAND  */
    WIRE = 306,                    /* WIRE  */
    WOR = 307,                     /* WOR  */
    Real = 308,                    /* Real  */
    Binary = 309,                  /* Binary  */
    PositiveInteger = 310,         /* PositiveInteger  */
    PositiveHugeInteger = 311,     /* PositiveHugeInteger  */
    Identifier = 312,              /* Identifier  */
    IdentifierCode = 313,          /* IdentifierCode  */
    Reference = 314,               /* Reference  */
    InvalidCharacter = 315         /* InvalidCharacter  */
  };
  typedef enum vcd_tokentype vcd_token_kind_t;
#endif

/* Value type.  */
#if ! defined VCD_STYPE && ! defined VCD_STYPE_IS_DECLARED
union VCD_STYPE
{
#line 79 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"

  char * ident;
  char * value;
  int integer;
  double real;
  enum vcd_vartypes vtype;
  enum vcd_scopes stype;
  struct vcd_vardef * vardef;
  struct vcd_change * change;
  struct vcd_scope * scope;
  struct vcd_changeset * changeset;
  struct vcd_range * range;

#line 146 "parse_vcd.hpp"

};
typedef union VCD_STYPE VCD_STYPE;
# define VCD_STYPE_IS_TRIVIAL 1
# define VCD_STYPE_IS_DECLARED 1
#endif


extern VCD_STYPE vcd_lval;


int vcd_parse (void);


#endif /* !YY_VCD_PARSE_VCD_HPP_INCLUDED  */
